@@ -41,12 +41,10 @@ INSTALLED_APPS = (
     "django.contrib.contenttypes",
     "django.contrib.sessions",
     "django.contrib.sites",
-    "django.contrib.redirects",
     "mezzanine.core",
     "mezzanine.blog",
     "mezzanine.pages",
     "mezzanine.twitter",
-    "mezzanine.forms",
 )
 
 TEMPLATE_CONTEXT_PROCESSORS = (
